# Generated by Django 5.0.6 on 2024-10-16 23:22

import uuid

import django.contrib.postgres.indexes
import django.contrib.postgres.search
import django.db.models.deletion
import django.utils.timezone
import phonenumber_field.modelfields
from django.conf import settings
from django.db import migrations, models

import pycorpkit.common.models.attachment


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Attachments",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("active", models.BooleanField(default=True)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                (
                    "content_type",
                    models.CharField(
                        choices=[
                            ("image/png", "PNG"),
                            ("image/jpeg", "JPEG"),
                            ("application/pdf", "PDF"),
                            ("application/vnd.ms-excel", "xlsx"),
                            ("application/msword", "doc"),
                            (
                                "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
                                "docx",
                            ),
                            (
                                "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
                                "xlsx",
                            ),
                        ],
                        max_length=100,
                    ),
                ),
                (
                    "uploaded_file",
                    models.FileField(
                        max_length=500,
                        upload_to=pycorpkit.common.models.attachment.upload_to,
                    ),
                ),
                ("title", models.CharField(max_length=255)),
                ("description", models.TextField(blank=True, null=True)),
                (
                    "size",
                    models.IntegerField(
                        blank=True,
                        help_text="The size of the attachment in bytes",
                        null=True,
                    ),
                ),
            ],
            options={
                "ordering": ("-updated", "-created"),
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Person",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("active", models.BooleanField(default=True)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                ("first_name", models.CharField(max_length=100)),
                ("last_name", models.CharField(max_length=100)),
                ("date_of_birth", models.DateField(blank=True, null=True)),
                ("surname", models.CharField(blank=True, max_length=255, null=True)),
                (
                    "gender",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("MALE", "Male"),
                            ("FEMALE", "Female"),
                            ("OTHER", "Other"),
                        ],
                        max_length=16,
                        null=True,
                    ),
                ),
                ("id_number", models.CharField(blank=True, max_length=255, null=True)),
                ("longitude", models.CharField(blank=True, max_length=100, null=True)),
                ("latitude", models.CharField(blank=True, max_length=100, null=True)),
            ],
            options={
                "ordering": ("-updated", "-created"),
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Organisation",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("active", models.BooleanField(default=True)),
                ("deleted", models.BooleanField(default=False)),
                ("email_address", models.EmailField(blank=True, max_length=50)),
                (
                    "phone_number",
                    phonenumber_field.modelfields.PhoneNumberField(
                        blank=True, max_length=128, region=None
                    ),
                ),
                ("physical_address", models.TextField(blank=True)),
                ("postal_address", models.CharField(blank=True, max_length=100)),
                ("name", models.CharField(db_index=True, max_length=255, unique=True)),
                (
                    "registration_number",
                    models.CharField(blank=True, max_length=255, null=True),
                ),
                ("kra_number", models.CharField(blank=True, max_length=255, null=True)),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("SUSPENDED", "Suspended"),
                            ("REJECTED", "Rejected"),
                            ("VERIFIED", "Verified"),
                            ("UNVERIFIED", "Unverified"),
                        ],
                        default="UNVERIFIED",
                        max_length=20,
                    ),
                ),
                (
                    "parent",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="children",
                        to="common.organisation",
                    ),
                ),
            ],
            options={
                "ordering": ("-updated", "-created"),
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="OrganisationAttachment",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("active", models.BooleanField(default=True)),
                ("deleted", models.BooleanField(default=False)),
                ("email_address", models.EmailField(blank=True, max_length=50)),
                (
                    "phone_number",
                    phonenumber_field.modelfields.PhoneNumberField(
                        blank=True, max_length=128, region=None
                    ),
                ),
                ("physical_address", models.TextField(blank=True)),
                ("postal_address", models.CharField(blank=True, max_length=100)),
                (
                    "attachment",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="attachments_organisation",
                        to="common.attachments",
                    ),
                ),
                (
                    "organisation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="organisation_attachments",
                        to="common.organisation",
                    ),
                ),
            ],
            options={
                "ordering": ("-updated", "-created"),
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="PersonContact",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("active", models.BooleanField(default=True)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                (
                    "contact_type",
                    models.CharField(
                        choices=[
                            ("email", "E-mail Address"),
                            ("phone_number", "Phone Number"),
                        ],
                        max_length=50,
                    ),
                ),
                ("contact_value", models.CharField(max_length=50)),
                ("verified", models.BooleanField(default=False)),
                ("is_primary", models.BooleanField(default=False)),
                (
                    "person",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="person_contacts",
                        to="common.person",
                    ),
                ),
            ],
            options={
                "ordering": ("-updated", "-created"),
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="UserProfile",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("active", models.BooleanField(default=True)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                ("is_organisation", models.BooleanField(default=False)),
                (
                    "search_vector",
                    django.contrib.postgres.search.SearchVectorField(null=True),
                ),
                (
                    "person",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT, to="common.person"
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="user_profile",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="UserProfileAttachment",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("active", models.BooleanField(default=True)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("created_by", models.UUIDField(blank=True, null=True)),
                ("updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("updated_by", models.UUIDField(blank=True, null=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                (
                    "attachment",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="attachments_profiles",
                        to="common.attachments",
                    ),
                ),
                (
                    "profile",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="user_profile_attachments",
                        to="common.userprofile",
                    ),
                ),
            ],
            options={
                "ordering": ("-updated", "-created"),
                "abstract": False,
            },
        ),
        migrations.AddIndex(
            model_name="userprofile",
            index=django.contrib.postgres.indexes.GinIndex(
                fields=["search_vector"], name="common_user_search__6e0ab2_gin"
            ),
        ),
    ]
